clear
set more off
capture log close

local dtaf "/Volumes/Schwartzunix/doren_schwartz/dta"
local logf "/Volumes/Schwartzunix/doren_schwartz/do"
local gphf "/Volumes/Schwartzunix/doren_schwartz/graphs"


*FILE: 		 SIPP_desc121519_all.do
*PURPOSE:	 Run analyses for trends in years spent as mothers of young children 

log using "`logf'/SIPP_desc121519_all.log", replace


use "`dtaf'/SIPP_step1_w14.dta", clear 

describe

*Collapse years of schooling <10 & 10-11 into 1 group: <12
 recode educ5 1=2, gen(educ4)
 replace educ4 = educ4-1

 lab def educ4_lbl 1 "1:<12" 2 "2:12" 3 "3:13-15" 4 "4:16+"
 lab val educ4 educ4_lbl
 lab var educ4 "4-category ed var"

 
 *Check the 2 education category variables created correctly 
 tab educ5 educ4, miss

tabstat tceb if tagegt40 == 1, by(tdob_byea) stat(mean n) 

*Generate year turned 40 variable
gen yr_40 = tdob_byear+40

*generate year turned 40 5-year categories
gen     yr_40c = 1 if yr_40 >= 1960 & yr_40 < 1970
replace yr_40c = 2 if yr_40 >= 1970 & yr_40 < 1980
replace yr_40c = 3 if yr_40 >= 1980 & yr_40 < 1990
replace yr_40c = 4 if yr_40 >= 1990 & yr_40 < 2000
replace yr_40c = 5 if yr_40 >= 2000 & yr_40 < 2010
replace yr_40c = 6 if yr_40 >= 2010 & yr_40 < 2020

lab def yr_40c_lbl 1 "1967-69" 2 "1970-79" 3 "1980-89" 4 "1990-99" 5 "2000-09" 6 "2010-17"
lab val yr_40c yr_40c_lbl
 
 *Check 
 tab yr_40 yr_40c, miss

*Create the sample
 
  *Drop people with missing value on the children ever born variable
   tab tceb, miss
   drop if tceb == .
   tab tceb

   ******* N=21,226*******  
   tab tceb empf, miss

*Tab trends of completed fertility by education
bysort educ4: tabstat tceb, by(yr_40c) stat(mean n)  

*Tab distributions by education and cohort (year turned 40) 
tab educ4 yr_40c [aw=wpfinwgt], col nofreq


*****************************************
* OVERALL TRENDS IN COMPLETED FERTILITY *
*****************************************

* Graph the overall trend in completed fertility [NOT IN PAPER]
preserve

collapse tceb [pw=wpfinwgt], by(yr_40)

cd `gphf'

twoway connected  tceb yr_40
    graph export SIPP_desc121519_all1.pdf, fontface(Times) replace 

restore

*****************************************
* TRENDS IN COMPLETED FERTILITY BY EDUC *
*****************************************


    ****FIGURE 1, PANEL A: ALL WOMEN****

preserve

collapse tceb [pw=wpfinwgt], by(yr_40c educ4)

reshape wide tceb, i(yr_40c) j(educ4)

lab val yr_40c yr_40c_lbl


cd `gphf'

lab var tceb1 "< High School"
lab var tceb2 "High School"
lab var tceb3 "Some College"
lab var tceb4 "College or More"

lab var yr_40c "Year Turned 40"

#delimit ;
twoway connected  tceb1 tceb2 tceb3 tceb4  yr_40c,  
       lcolor(gs0 gs0 gs0 gs0) lpattern(dash_dot shortdash longdash  solid) msymbol(T Oh S Th) mcolor(gs0 gs0 gs0 gs0)
       xlabel(1 "1967-69" 2 "1970-79" 3 "1980-89" 4 "1990-99" 5 "2000-09" 6 "2010-17", labsize(small)) 
       ytitle("Completed Fertility") 
       scheme(s1color) graphregion(fcolor(gs16)) plotregion(style(none)) 
       legend(subtitle("Education Category", size(*.9)) size(*.9)) ;

graph export SIPP_desc121519_all2.pdf, fontface(Times) replace  ;
    
restore ;

#delimit cr

    ****FIGURE 1, PANEL B: FOR WOMEN WITH CHILDREN****

preserve

collapse tceb [pw=wpfinwgt] if tceb > 0, by(yr_40c educ4)

reshape wide tceb, i(yr_40c) j(educ4)

lab val yr_40c yr_40c_lbl

*Save a file for women with children 
sort yr_40c
tempfile cf
save `cf'

cd `gphf'

lab var tceb1 "< High School"
lab var tceb2 "High School"
lab var tceb3 "Some College"
lab var tceb4 "College or More"

lab var yr_40c "Year Turned 40"

#delimit ;
twoway connected  tceb1 tceb2 tceb3 tceb4  yr_40c,  
       lcolor(gs0 gs0 gs0 gs0) lpattern(dash_dot shortdash longdash  solid) msymbol(T Oh S Th) mcolor(gs0 gs0 gs0 gs0)
       xlabel(1 "1967-69" 2 "1970-79" 3 "1980-89" 4 "1990-99" 5 "2000-09" 6 "2010-17", labsize(small)) 
       ytitle("Completed Fertility") 
       scheme(s1color) graphregion(fcolor(gs16)) plotregion(style(none)) 
       legend(subtitle("Education Category", size(*.9)) size(*.9)) ;

graph export SIPP_desc121519_all2b.pdf, fontface(Times) replace  ;
    
restore ;

#delimit cr

    ****FIGURE 2. TRENDS IN THE PROPORTION OF WOMEN WITH NON-ZERO COMPLETED FERTILITY****

preserve

gen wkids = (tceb > 0)
replace wkids = . if tceb == .

collapse wkids [pw=wpfinwgt], by(yr_40c educ4)

reshape wide wkids, i(yr_40c) j(educ4)

lab val yr_40c yr_40c_lbl

sort yr_40c
tempfile wkids
save `wkids'

cd `gphf'

lab var wkids1 "< High School"
lab var wkids2 "High School"
lab var wkids3 "Some College"
lab var wkids4 "College or More"

lab var yr_40c "Year Turned 40"

#delimit ;
twoway connected  wkids1 wkids2 wkids3 wkids4  yr_40c,  
       lcolor(gs0 gs0 gs0 gs0) lpattern(dash_dot shortdash longdash  solid) msymbol(T Oh S Th) mcolor(gs0 gs0 gs0 gs0)
       xlabel(1 "1967-69" 2 "1970-79" 3 "1980-89" 4 "1990-99" 5 "2000-09" 6 "2010-17", labsize(small)) 
       ytitle("Proportion with Children") 
       ylabel(.5(.1)1) yscale(r(.5 1))
       scheme(s1color) graphregion(fcolor(gs16)) plotregion(style(none)) 
       legend(subtitle("Education Category", size(*.9)) size(*.9)) ;

graph export SIPP_desc121519_all2c.pdf, fontface(Times) replace  ;
    
restore ;

#delimit cr

	****APPENDIX TABLE 1. STATISTICS OF COMPLETED FERTILITY BY MPF STATUS****
	
preserve

collapse tceb [pw=wpfinwgt] , by(yr_40c educ4 empf)

reshape wide tceb, i(yr_40c empf) j(educ4)

lab val yr_40c yr_40c_lbl

sort yr_40c

cd `gphf'

lab var tceb1 "< High School"
lab var tceb2 "High School"
lab var tceb3 "Some College"
lab var tceb4 "College or More"

lab var yr_40c "Year Turned 40"

*[NOT IN PAPER] 
#delimit ;
twoway connected  tceb1 tceb2 tceb3 tceb4  yr_40c, by(empf)
       lcolor(gs0 gs0 gs0 gs0) lpattern(dash_dot shortdash longdash  solid) msymbol(T Oh S Th) mcolor(gs0 gs0 gs0 gs0)
       xlabel(1 "1967-69" 2 "1970-79" 3 "1980-89" 4 "1990-99" 5 "2000-09" 6 "2010-17", angle(45)) 
       ytitle("Completed Fertility") 
       scheme(s1color) graphregion(fcolor(gs16)) plotregion(style(none)) 
       legend(subtitle("Education Category", size(*.9)) size(*.9)) ;

graph export SIPP_desc121519_all2_mpf.pdf, fontface(Times) replace  ;


list if empf == 1 & yr_40c == 1 ;

list if empf == 1 & yr_40c == 6 ;

list if empf == 2 & yr_40c == 1 ;

list if empf == 2 & yr_40c == 6 ;
 
drop if empf == . ;
tab empf ;

/*empf 1=Yes, 2=No*/
reshape wide tceb1-tceb4, i(yr_40c) j(empf) ;

sort yr_40c ;


tempfile mpf_cf ;
save `mpf_cf' ;
  
restore ;

#delimit cr


tab tceb empf , miss

****************************
* MPF TRENDS BY EDUCUATION *
****************************
		
        ***FIGURE 5. Trends in Multiple Partner Fertility by Education***

gen mpf=(empf==1)
replace mpf=. if empf==.
tab mpf empf, miss
tab tceb mpf, miss

preserve

collapse mpf [aw=wpfinwgt], by (yr_40c educ4)

reshape wide mpf, i(yr_40c) j(educ)

*Save a file for MPF analyeses later (for table 2)
sort yr_40c
tempfile mpf
save `mpf'

cd `gphf'

lab var mpf1 "< High School"
lab var mpf2 "High School"
lab var mpf3 "Some College"
lab var mpf4 "College or More"
lab var yr_40c "Year Turned 40"


*Defined for all women with children (not just two or more)
#delimit ;
twoway connected mpf1 mpf2 mpf3 mpf4 yr_40c, 
		lcolor(gs0 gs0 gs0 gs0) lpattern(dash_dot shortdash longdash  solid) msymbol(T Oh S Th) mcolor(gs0 gs0 gs0 gs0)
		xlabel(1 "1967-69" 2 "1970-79" 3 "1980-89" 4 "1990-99" 5 "2000-09" 6 "2010-17", labsize(small)) 
		ytitle("Proportion with MPF") 
		scheme(s1color) graphregion(fcolor(gs16)) plotregion(style(none)) 
		legend(subtitle("Education Category", size(*.9)) size(*.9)) ;
   
graph export SIPP_desc121519_all2_mpf2.pdf, fontface(Times) replace ;


*For text statistics about prevalence of MPF in last period [in paper SECTION 4.2];
list if yr_40c == 6 ;

restore ;

#delimit cr

*For text statistics about relationship between mpf and fertility [in paper SECTION 4.2] 
reg tceb mpf i.educ4 i.yr_40c [pw=wpfinwgt]


*******************
** BIRTH SPACING **
*******************

*Reshape data long
 
keep tcbyr* ssuid spanel swave pnum wpfinwgt educ4 yr_40* empf tceb
 
reshape long tcbyr_, i(ssuid spanel swave pnum) j(childno) 

* generate a variable for birth spacing 
sort ssuid spanel swave pnum tcbyr_ 
by ssuid spanel swave pnum: gen diff_kage = tcbyr - tcbyr[_n-1] 
list ssuid spanel swave pnum tcbyr diff_kage in 1/25

tab diff_kage
 
*Topcode at 15 years for birth spacing
replace diff_kage = 15 if diff_kage > 15 & diff_kage ~= .

lab var diff_kage "Difference in birth year, topcoded at 15"

tab diff_kage

*Calculations based on average spacing per woman, not average across births (average across births weight
  *women with more children more heavily)

collapse diff_kage wpfinwgt educ4 yr_40 yr_40c empf tceb, by(ssuid spanel swave pnum)
list ssuid spanel swave pnum diff_kage in 1/25
  
lab val empf empf_lbl  

*Within categories of education, do those with MPF have wider birth spacing? 
bysort educ4: tabstat diff_kage [aw=wpfinwgt], by(empf) stat(mean n)  

gen mpf=(empf==1)
replace mpf=. if empf==.


 ***For text statistics of relationship between mpf and fertility [in paper Section 4.2]
xi: reg diff_kage i.mpf i.yr_40c i.educ4 [pw=wpfinwgt]


**************************************************************************
* Years spent at the individual level (not calculated using equation (1) *
**************************************************************************

**************** SECOND FOOTNOTE IN PAPER **************** 
	
   *crs 1/12/20::: Equation 1 is an aggregate formula. It will not exactly equal
   *               the average of individuals. To check to see how far off it is
   *               compute trends in years spent at the individual level and then
   *			   take the average. (Equation 1 takes average and then computes
   *			   average years spent from these.)

		
gen     ind_yrs = 0 if tceb == 0 
replace ind_yrs = 6 if tceb == 1 
replace ind_yrs = 6 + ((tceb-1)*diff_kage) if tceb > 1


list ind_yrs tceb diff_kage in 1/50

preserve
collapse ind_yrs [aw=wpfinwgt], by(yr_40c educ4)
reshape wide ind_yrs, i(yr_40c) j(educ)

cd `gphf'
lab var ind_yrs1 "< High School"
lab var ind_yrs2 "High School"
lab var ind_yrs3 "Some College"
lab var ind_yrs4 "College or More"

lab var yr_40c "Year Turned 40"

 
*The trends are very similar between those produced by Equation (1) and the individual-
    *level averages but the levels of the individual-level averages are somewhat lower.

#delimit ;
twoway connected  ind_yrs1 ind_yrs2 ind_yrs3 ind_yrs4 yr_40c,  
	   lcolor(gs0 gs0 gs0 gs0) lpattern(dash_dot shortdash longdash  solid) msymbol(T Oh S Th) mcolor(gs0 gs0 gs0 gs0)
	   xlabel(1 "1967-69" 2 "1970-79" 3 "1980-89" 4 "1990-99" 5 "2000-09" 6 "2010-17", labsize(small)) 
	   ytitle("Years Spent as Mothers to Young Children") 
	   scheme(s1color) graphregion(fcolor(gs16)) plotregion(style(none)) 
	   legend(subtitle("Education Category", size(*.9)) size(*.9)) ylabel(8(2)16) yscale(r(8 16)) ;

graph export SIPP_desc121519_all5_ind.pdf, fontface(Times) replace ;

#delimit cr

**************** TABLE 1 COLUMNS A & B **************** 

list ind_yrs* if yr_40c == 6 | yr_40c == 1

restore


*****************************
* OVERALL TRENDS IN SPACING *
*****************************

*[NOT IN PAPER]
preserve

collapse diff_kage [aw=wpfinwgt], by(yr_40)

cd `gphf'

twoway connected  diff_kage yr_40
    graph export SIPP_desc121519_all3.pdf, fontface(Times) replace 

restore


*****************************
* TRENDS IN SPACING BY EDUC *
*****************************

	****FIGURE 3. Trends in Birth Spacing by Education **** 
preserve

collapse diff_kage [aw=wpfinwgt], by(yr_40c educ4)
reshape wide diff_kage, i(yr_40c) j(educ)

sort yr_40c
tempfile spacing
save `spacing'

cd `gphf'

lab var diff_kage1 "< High School"
lab var diff_kage2 "High School"
lab var diff_kage3 "Some College"
lab var diff_kage4 "College or More"

lab var yr_40c "Year Turned 40"

*Defined by women with 2 or more children 
#delimit ;
twoway connected  diff_kage1 diff_kage2 diff_kage3 diff_kage4 yr_40c,  
       lcolor(gs0 gs0 gs0 gs0) lpattern(dash_dot shortdash longdash  solid) msymbol(T Oh S Th) mcolor(gs0 gs0 gs0 gs0)
       xlabel(1 "1967-69" 2 "1970-79" 3 "1980-89" 4 "1990-99" 5 "2000-09" 6 "2010-17", labsize(small)) 
       ytitle("Years Between Births") 
       scheme(s1color) graphregion(fcolor(gs16)) plotregion(style(none)) 
       legend(subtitle("Education Category", size(*.9)) size(*.9)) ;

    graph export SIPP_desc121519_all4.pdf, fontface(Times) replace ;

restore ;
  
#delimit cr

 
**************** APPENDIX TABLE 1. STATISTICS OF BIRTH SPACING BY MPF STATUS**************** 

preserve

collapse diff_kage [aw=wpfinwgt], by(yr_40c educ4 empf)
reshape wide diff_kage, i(yr_40c empf) j(educ)

sort yr_40c

cd `gphf'

lab var diff_kage1 "< High School"
lab var diff_kage2 "High School"
lab var diff_kage3 "Some College"
lab var diff_kage4 "College or More"

lab var yr_40c "Year Turned 40"
lab var empf "Do you have multiple partner fertility?"

*[GRAPH NOT IN PAPER]
#delimit ;
twoway connected  diff_kage1 diff_kage2 diff_kage3 diff_kage4 yr_40c, by(empf)  
       lcolor(gs0 gs0 gs0 gs0) lpattern(dash_dot shortdash longdash  solid) msymbol(T Oh S Th) mcolor(gs0 gs0 gs0 gs0)
       xlabel(1 "1967-69" 2 "1970-79" 3 "1980-89" 4 "1990-99" 5 "2000-09" 6 "2010-17", angle(45)) 
       ytitle("Years between Births") 
       scheme(s1color) graphregion(fcolor(gs16)) plotregion(style(none)) 
       legend(subtitle("Education Category", size(*.9)) size(*.9)) ;

    graph export SIPP_desc121519_all4_mpf.pdf, fontface(Times) replace ;


list if empf == 1 & yr_40c == 1 ;
list if empf == 1 & yr_40c == 6 ;
list if empf == 2 & yr_40c == 1 ;
list if empf == 2 & yr_40c == 6 ;

drop if empf == . ;
tab empf ;

/*empf 1=Yes, 2=No*/
reshape wide diff_kage1-diff_kage4, i(yr_40c) j(empf) ;

sort yr_40c ;

tempfile mpf_spacing ;
save `mpf_spacing' ;


restore ;
  
#delimit cr


************************
* YEARS SPENT ANALYSIS *
************************


use `cf', clear          /*completed fertility*/
 

sort yr_40c 

merge yr_40c using `spacing'  /*spacing file*/

tab _merge
drop _merge

sort yr_40c 

merge yr_40c using `wkids' /*Percent with chidlren file*/

tab _merge 
drop _merge 


sort yr_40c 

merge yr_40c using `mpf' /* percent of mpf */
drop _merge

sort yr_40c

merge yr_40c using `mpf_spacing' /*spacing by mpf*/

tab _merge
drop _merge 

sort yr_40c


merge yr_40c using `mpf_cf' /*completed fertility by mpf*/

tab _merge
drop _merge


*EQUATION 1: average years spent with children under 6 


forval i = 1/4 { 
 gen twk`i' = wkids`i'*(6 + ((tceb`i'-1)*diff_kage`i'))  /*years/time spent with kids - observed*/
 }


cd `gphf'
lab var twk1 "< High School"
lab var twk2 "High School"
lab var twk3 "Some College"
lab var twk4 "College or More"

lab var yr_40c "Year Turned 40"

	***FIGURE 4. Trends in Estimated Years Spent as Mothers of Young Children by Education***

#delimit ;
twoway connected  twk1 twk2 twk3 twk4 yr_40c,  
       lcolor(gs0 gs0 gs0 gs0) lpattern(dash_dot shortdash longdash  solid) msymbol(T Oh S Th) mcolor(gs0 gs0 gs0 gs0)
       xlabel(1 "1967-69" 2 "1970-79" 3 "1980-89" 4 "1990-99" 5 "2000-09" 6 "2010-17", labsize(small)) 
       ytitle("Years Spent as Mothers to Young Children") 
       scheme(s1color) graphregion(fcolor(gs16)) plotregion(style(none)) 
       legend(subtitle("Education Category", size(*.9)) size(*.9)) ylabel(8(2)16) yscale(r(8 16)) ;

    graph export SIPP_desc121519_all5.pdf, fontface(Times) replace ;

#delimit cr
 
**************** TABLE 1 COLUMNS A & B **************** 

list twk* if yr_40c == 6 | yr_40c == 1 



*EQUATION 2: estimate the contribution of changes in birth spacing to trends in years spent as mothers of young children

reshape long tceb diff_kage twk wkids mpf, i(yr_40c) j(educ4)
reshape wide tceb diff_kage twk wkids mpf, i(educ4)  j(yr_40c)

forval i = 1/6 {
 gen c3twk`i' = wkids`i'*(6 + ((tceb`i'-1)*diff_kage1)) /* proportion of having kids & completed fertility are as observed, spacing stays at initial period*/
}

reshape long tceb diff_kage twk c3twk wkids mpf, i(educ4)  j(yr_40c)
reshape wide tceb diff_kage twk c3twk wkids mpf, i(yr_40c) j(educ4)

*[GRAPH NOT IN PAPER]
cd `gphf'
lab var c3twk1 "< High School"
lab var c3twk2 "High School"
lab var c3twk3 "Some College"
lab var c3twk4 "College or more"
lab var twk1 "< High School"
lab var twk2 "High School"
lab var twk3 "Some College"
lab var twk4 "College or more"

lab var yr_40c "Year Turned 40"

twoway connected  c3twk1 c3twk2 c3twk3 c3twk4 yr_40c , xlabel(1 "1967-69" 2 "1970-79" 3 "1980-89" 4 "1990-99" 5 "2000-09" 6 "2010-17") ytitle("Years Spent as Mothers of Young Children") 
    graph export SIPP_desc121519_all6.pdf, fontface(Times) replace 

**************** TABLE 1 COLUMNS A & C****************

list c3twk* if yr_40c == 6 | yr_40c == 1



*EQUATION 3: estimate the contribution of increases in the prevalence of MPF to trends in years spent as mothers of young children
	*** If there had been no changes in MPF, what would trends in years spent have been?


forval i = 1/4 {
 #delimit ;

  /*empf 1=yes, 2=no*/

  gen cf4_twk`i' = wkids`i'*(mpf`i'[1]* (6 + ((tceb`i'1-1) * diff_kage`i'1) ) + 

                           ((1 - mpf`i'[1]) * (6 + ((tceb`i'2 - 1) * diff_kage`i'2) ) )) ;
 #delimit cr

 }

/*row [a] in table 2 is not exactly the same because of the non-linearity of the equation*/
list wkids1 mpf1 tceb11 tceb12 diff_kage11 diff_kage12 cf4_twk1 twk1

**************** TABLE 2 COLUMNS A & C ****************

list cf4_twk* 



*EQUATION 4, quantify the relative impact of the increase in MPF prevalence (compositional effects) versus birth spacing
	*** If there had been no changes in MPF OR SPACING, what would trends in years spent have been?

	
forval i = 1/4 {
 #delimit ;

  /*empf 1=yes, 2=no*/

  gen cf5_twk`i' = wkids`i'*(mpf`i'[1]* (6 + ((tceb`i'1-1) * diff_kage`i'1[1]) ) + 

                           ((1 - mpf`i'[1]) * (6 + ((tceb`i'2 - 1) * diff_kage`i'2[1]) ) )) ;
 #delimit cr

 }

/*row [a] in table 2 is not exactly the same because of the non-linearity of the equation*/
list wkids1 mpf1 tceb11 tceb12 diff_kage11 diff_kage12 cf5_twk1 twk1

**************** TABLE 2 COLUMNS A & D **************** 

list cf5_twk* 


log close 

 




