capture log close
set more off



local dtaf "/Volumes/Schwartzunix/doren_schwartz/dta"
local logf "/Volumes/Schwartzunix/doren_schwartz/do"
local gphf "/Volumes/Schwartzunix/doren_schwartz/graphs"

*FILE: 		 census_numberofkids.do
*PURPOSE:	 Read in Census and ACS data to calculate number of children in
*			 household and birth spacing 

log using "`logf'/census_numberofkids.log", replace


use "`dtaf'/usa_00013.dta", clear

describe


*keep women and kids
keep if sex == 2 | age <= 18

tab age sex 
tab educ

gen educ5     = 1 if educ < 4.             /*lt 10*/
replace educ5 = 2 if educ >= 4 & educ <= 5 /*10-11*/
replace educ5 = 3 if educ == 6             /*12*/
replace educ5 = 4 if educ >= 7 & educ <= 9 /*SC*/
replace educ5 = 5 if educ >=10 & educ <=11 /*college+*/

label def educ5_lbl 1 "1:lt 10" 2 "2:10-11" 3 "3:12" 4 "4:13-15" 5 "5:16+"
label val educ5 educ5_lbl

*check
tab educ educ5, miss

*Collapse <10 & 10-11 group
 recode educ5 1=2, gen(educ4)
 replace educ4 = educ4-1

 lab def educ4_lbl 1 "1:<12" 2 "2:12" 3 "3:13-15" 4 "4:16+"
 lab val educ4 educ4_lbl
 lab var educ4 "4-category ed var"

 *check
 tab educ5 educ4, miss

sort year datanum serial pernum 
list year serial pernum age momloc in 1/10, nolabel
list year serial pernum age momloc if (serial == 32 & year == 1940) | (serial == 56 & year == 1940) | (serial == 68 & year == 1940), nolabel
list year serial pernum subfam age momloc if serial ==  825625 & year == 2017, nolab


*Create separate data sets for kids 0-18 years of age and moms and merge together
preserve
keep if momloc ~= 0 & age <= 18 /*kids with mothers in household*/
keep year serial datanum age momloc

rename age kid_age
rename momloc pernum

sort year serial datanum pernum

tempfile kid
save `kid'

restore

*Moms file
sort year serial datanum pernum

*Now merge on kids to moms
merge year serial datanum pernum using `kid'

*save merged file
tempfile merge
save `merge'


list year serial pernum sex age kid_age _merge if (serial == 32 & year == 1940) | (serial == 56 & year == 1940) | (serial == 68 & year == 1940), nolabel
list year serial pernum subfam sex age kid_age _merge  if serial ==  825625 & year == 2017, nolab

tab _merge
*1s are the umatched women (without kids)
*2s are the unmatched babies (there are none of these)


*CALCULATE AVERAGE NUMBER OF KIDS IN HOUSEHOLD PER WOMAN BY EDUCATION (for women aged 25-59)

    /*

	*Note: these children are not just bio children. from
	        https://usa.ipums.org/usa-action/variables/MOMLOC#description_section
	
	"MOMLOC identifies social relationships (such as stepmother and adoptive mother) 
	 as well as biological relationships. For 1970 and later, MOMLOC will also identify 
	 the unmarried partner of a child's father identified with POPLOC"
	 
	 
    */	 

   gen nkid = (_merge == 3)  /*kids are records that were successfully matched to mothers*/
   sort year serial datanum pernum
   list year serial pernum sex age kid_age _merge nkid if (serial == 32 & year == 1940) | (serial == 56 & year == 1940) | (serial == 68 & year == 1940), nolabel

   keep if age >= 25 & age <= 59

   list year serial pernum sex age kid_age _merge nkid educ4 in 1/20


   *Number of kids 0-18 in household per woman -- excluding those who have 0 kids
    collapse (sum) nkid (mean) educ4 perwt if nkid~=0, by(year serial datanum pernum) 



   *check 
   list year serial pernum nkid educ4 in 1/20

    
******************************************
* OVERALL TRENDS IN NUMBERS IN HOUSEHOLD *
******************************************

   preserve

   collapse nkid [aw=perwt], by(year)

   cd `gphf'

   twoway connected nkid year
	   graph export census_numberofkids1.pdf, fontface(Times) replace 

   restore

*****************************
* TRENDS IN NUMBERS BY EDUC *
*****************************


   preserve

   collapse nkid [aw=perwt], by(year educ4)
   reshape wide nkid, i(year) j(educ)

   cd `gphf'

   lab var nkid1 "<12"
   lab var nkid2 "12"
   lab var nkid3 "13-15"
   lab var nkid4 "16+"

   lab var year "Year"

   drop if year < 1960

   twoway connected  nkid1 nkid2 nkid3 nkid4 year, ytitle("Number of Children in Household") xlabel(1960 1970 1980 1990 2000 2010 2017)
	   graph export census_numberofkids2.pdf, fontface(Times) replace 

   restore



************************
* FOR SPACING ANALYSIS *
************************

use `merge', clear


*drop the unmatched women; there are no unmatched kids
drop if _merge == 1
drop _merge

sort year serial datanum pernum kid_age
list year serial pernum sex age kid_age if (serial == 32 & year == 1940) | (serial == 56 & year == 1940) | (serial == 68 & year == 1940), nolabel


*look at this only for mothers age 25-59. 
keep if age >= 25 & age <= 59


*CALCULATE SPACING MEASURE
by year serial datanum pernum: gen diff_kage = kid_age - kid_age[_n-1] 
list year serial pernum sex age kid_age diff_kage if (serial == 32 & year == 1940) | (serial == 56 & year == 1940) | (serial == 68 & year == 1940), nolabel

tab diff_kage

*Average spacing per woman, not average across births (average across births weight
*women with more children more heavily)

collapse diff_kage perwt educ4, by(year serial datanum pernum)
list year serial pernum diff_kage if (serial == 32 & year == 1940) | (serial == 56 & year == 1940) | (serial == 68 & year == 1940), nolabel


*****************************
* OVERALL TRENDS IN SPACING *
*****************************

preserve

collapse diff_kage [aw=perwt], by(year)

cd `gphf'

twoway connected  diff_kage year
    graph export census_numberofkids3.pdf, fontface(Times) replace 

restore


*****************************
* TRENDS IN SPACING BY EDUC *
*****************************

collapse diff_kage [aw=perwt], by(year educ4)
reshape wide diff_kage, i(year) j(educ)

cd `gphf'

lab var diff_kage1 "<12"
lab var diff_kage2 "12"
lab var diff_kage3 "13-15"
lab var diff_kage4 "16+"

lab var year "Year"

drop if year < 1960


#delimit ;
twoway connected  diff_kage1 diff_kage2 diff_kage3 diff_kage4 year,  
       lcolor(gs0 gs0 gs0 gs0) lpattern(dash_dot shortdash longdash  solid) msymbol(T Oh S Th) mcolor(gs0 gs0 gs0 gs0)
       ylabel(2.5(.5)4.5) ytitle("Difference in Child Ages") xlabel(1960 1970 1980 1990 2000 2010 2017)
       scheme(s1color) graphregion(fcolor(gs16)) plotregion(style(none)) 
       legend(subtitle("Education Category", size(*.9)) size(*.9)) ;

    graph export census_numberofkids4.pdf, fontface(Times) replace ;

#delimit cr


log close
exit
